==> duiba-live-supplier-center-api-0.0.2-20220121.021621-62-sources.jar: cn/com/duiba/live/supplier/center/api/params/DuibaLiveSupplierGoodsAuditPageParam.java <==
package cn.com.duiba.live.supplier.center.api.params;

import cn.com.duiba.live.supplier.center.api.base.BasePage;

import java.util.Date;

/**
 * @author zhanghuifeng
 * @date 2022/1/10 15:46
 */
public class DuibaLiveSupplierGoodsAuditPageParam extends BasePage {

    private static final long serialVersionUID = 4730395480318138997L;

    /**
     * 兑吧商品ID
     */
    private Long duibaItemId;

    /**
     * 商品名称
     */
    private String goodsName;

    /**
     * 提交开始时间
     */
    private Date submitStartTime;

    /**
     * 提交结束时间
     */
    private Date submitEndTime;

    /**
     * 商品类型,coupon：优惠券 object：实物
     */
    private String goodsType;

    /**
     * 商品类目
     */
    private Long itemClassifyId;

    /**
     * 是否上架:0下架,1上架
     */
    private Integer enableState;

    /**
     * 审核状态:0待审核,1审核通过,2审核拒绝,3取消申请
     */
    private Integer auditState;

    /**
     * 审核类型:1兑吧审核,2供应商审核
     */
    private Integer auditType;

    /**
     * 供应商ID
     */
    private Long supplierId;

    public Long getDuibaItemId() {
        return duibaItemId;
    }

    public void setDuibaItemId(Long duibaItemId) {
        this.duibaItemId = duibaItemId;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }

    public Date getSubmitStartTime() {
        return submitStartTime;
    }

    public void setSubmitStartTime(Date submitStartTime) {
        this.submitStartTime = submitStartTime;
    }

    public Date getSubmitEndTime() {
        return submitEndTime;
    }

    public void setSubmitEndTime(Date submitEndTime) {
        this.submitEndTime = submitEndTime;
    }

    public String getGoodsType() {
        return goodsType;
    }

    public void setGoodsType(String goodsType) {
        this.goodsType = goodsType;
    }

    public Long getItemClassifyId() {
        return itemClassifyId;
    }

    public void setItemClassifyId(Long itemClassifyId) {
        this.itemClassifyId = itemClassifyId;
    }

    public Integer getEnableState() {
        return enableState;
    }

    public void setEnableState(Integer enableState) {
        this.enableState = enableState;
    }

    public Integer getAuditState() {
        return auditState;
    }

    public void setAuditState(Integer auditState) {
        this.auditState = auditState;
    }

    public Integer getAuditType() {
        return auditType;
    }

    public void setAuditType(Integer auditType) {
        this.auditType = auditType;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
}

==> duiba-live-supplier-center-api-0.0.3-20220124.081721-4-sources.jar: cn/com/duiba/live/supplier/center/api/params/DuibaLiveSupplierGoodsAuditPageParam.java <==
package cn.com.duiba.live.supplier.center.api.params;

import cn.com.duiba.live.supplier.center.api.base.BasePage;

import java.util.Date;

/**
 * @author zhanghuifeng
 * @date 2022/1/10 15:46
 */
public class DuibaLiveSupplierGoodsAuditPageParam extends BasePage {

    private static final long serialVersionUID = 4730395480318138997L;

    /**
     * 兑吧商品ID
     */
    private Long duibaItemId;

    /**
     * 供应商商品id
     */
    private Long supplierGoodsId;

    /**
     * 商品名称
     */
    private String goodsName;

    /**
     * 提交开始时间
     */
    private Date submitStartTime;

    /**
     * 提交结束时间
     */
    private Date submitEndTime;

    /**
     * 商品类型,coupon：优惠券 object：实物
     */
    private String goodsType;

    /**
     * 商品类目
     */
    private Long itemClassifyId;

    /**
     * 是否上架:0下架,1上架
     */
    private Integer enableState;

    /**
     * 审核状态:0待审核,1审核通过,2审核拒绝,3取消申请
     */
    private Integer auditState;

    /**
     * 审核类型:1兑吧审核,2供应商审核
     */
    private Integer auditType;

    /**
     * 供应商ID
     */
    private Long supplierId;

    public Long getSupplierGoodsId() {
        return supplierGoodsId;
    }

    public void setSupplierGoodsId(Long supplierGoodsId) {
        this.supplierGoodsId = supplierGoodsId;
    }

    public Long getDuibaItemId() {
        return duibaItemId;
    }

    public void setDuibaItemId(Long duibaItemId) {
        this.duibaItemId = duibaItemId;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }

    public Date getSubmitStartTime() {
        return submitStartTime;
    }

    public void setSubmitStartTime(Date submitStartTime) {
        this.submitStartTime = submitStartTime;
    }

    public Date getSubmitEndTime() {
        return submitEndTime;
    }

    public void setSubmitEndTime(Date submitEndTime) {
        this.submitEndTime = submitEndTime;
    }

    public String getGoodsType() {
        return goodsType;
    }

    public void setGoodsType(String goodsType) {
        this.goodsType = goodsType;
    }

    public Long getItemClassifyId() {
        return itemClassifyId;
    }

    public void setItemClassifyId(Long itemClassifyId) {
        this.itemClassifyId = itemClassifyId;
    }

    public Integer getEnableState() {
        return enableState;
    }

    public void setEnableState(Integer enableState) {
        this.enableState = enableState;
    }

    public Integer getAuditState() {
        return auditState;
    }

    public void setAuditState(Integer auditState) {
        this.auditState = auditState;
    }

    public Integer getAuditType() {
        return auditType;
    }

    public void setAuditType(Integer auditType) {
        this.auditType = auditType;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
}
